@@ -14,7 +14,7 @@ class BaseAPI:
 
     def _call(self, url, params={}, json_payload={}, headers={}):
         api_url = self.endpoint + url
-        headers['Api-Key'] = self.token
+        params["api_key"] = self.token
         r = requests.get(api_url, verify=self.verify, headers=headers, params=params, data=json_payload)
         if r.status_code >= 400:
             try:
@@ -34,6 +34,14 @@ class BaseAPI:
             df = pd.read_csv(BytesIO(r.content))
         return df
 
+    def _build_params(self, **kwargs):
+        params = {}
+        for param in kwargs:
+            if kwargs.get(param) is not None:
+                params[str(param)] = kwargs.get(param)
+        return params
+
+
 class ResponseCodeException(Exception):
     """
     Exception raised when the API returns an unexpected response code
